@@ -4,9 +4,9 @@ local $^W = 1;
 
 BEGIN {
     use base qw(Exporter);
-    use vars qw ( @EXPORT_OK );
+    use vars qw( @EXPORT_OK $VERSION );
+    $VERSION = '0.38';
     @EXPORT_OK   = qw(Get_Local_License Verify_Local_License);
-#    $VERSION     : taken from lib/ExtUtils/ModuleMaker.pm
 }
 
 my %licenses = (
