@@ -1,25 +1,22 @@
 package ExtUtils::ModuleMaker::Utility;
-# as of 09-02-2005
+# as of 09-04-2005
 use strict;
 local $^W = 1;
+use base qw(Exporter);
+use vars qw( @EXPORT_OK $VERSION );
+$VERSION = '0.38';
+@EXPORT_OK   = qw(
+    _get_home_directory
+    _preexists_mmkr_directory
+    _make_mmkr_directory
+    _restore_mmkr_dir_status
+    _identify_pm_files_in_personal_dir
+    _hide_pm_files_in_personal_dir
+    _reveal_pm_files_in_personal_dir
+);
 use Carp;
 use File::Path;
 
-BEGIN {
-    use base qw(Exporter);
-    use vars qw ( @EXPORT_OK );
-    @EXPORT_OK   = qw(
-        _get_home_directory
-        _preexists_mmkr_directory
-        _make_mmkr_directory
-        _restore_mmkr_dir_status
-        _identify_pm_files_in_personal_dir
-        _hide_pm_files_in_personal_dir
-        _reveal_pm_files_in_personal_dir
-    );
-#    $VERSION     : taken from lib/ExtUtils/ModuleMaker.pm
-}
-
 sub _get_home_directory {
     my $realhome;
     if ($^O eq 'MSWin32') {
@@ -131,40 +128,6 @@ sub _reveal_pm_files_in_personal_dir {
     }
 }
 
-#sub _hide_pm_files_in_personal_dir {
-#    my $mmkr_dir = shift;
-#    my $full_dir = "$mmkr_dir/ExtUtils/ModuleMaker/Personal";
-#    my @pm_files = glob("$full_dir/*.pm");
-#    my %pers;
-#    foreach my $f (@pm_files) {
-#        $pers{$f}{orig}    = $f;
-#        $pers{$f}{hidden}  = $f . '.hidden';
-#        $pers{$f}{atime}   = (stat($pers{$f}{orig}))[8];
-#        $pers{$f}{modtime} = (stat($pers{$f}{orig}))[9];
-#        rename $pers{$f}{orig},
-#               $pers{$f}{hidden}
-#            or croak "Unable to rename $pers{$f}{orig}: $!";
-#    }
-#    return { %pers };
-#}
-#
-#sub _reveal_pm_files_in_personal_dir {
-#    my $pers_def_ref = shift;
-#    my %pers = %{$pers_def_ref};
-#    foreach my $f (keys %pers) {
-#        if (-f $pers{$f}->{hidden} ) {
-#            rename $pers{$f}->{hidden},
-#                   $pers{$f}->{orig},
-#                or croak "Unable to rename $pers{$f}->{hidden}: $!";
-#            utime $pers{$f}->{atime}, 
-#                  $pers{$f}->{modtime}, 
-#                  ($pers{$f}->{orig});
-#        } else {
-#            croak "Unable to locate file $pers{$f}->{hidden} for restoring: $!";
-#        }
-#    }
-#}
-
 1;
 
 #################### DOCUMENTATION ####################
